<template>
  <el-menu router :default-active="defaultActive" background-color="transparent" :collapse="isCollapse"
    :unique-opened="getThemeConfig.isUniqueOpened" :collapse-transition="false">
    <!-- {{menuLists}} -->
    <template v-for="val in menuLists">
      <!-- 加载一级路由包含children 一级菜单-->
      <el-sub-menu :index="val.path" v-if="val.children && val.children.length > 0" :key="val.path">
        <template #title>
          <SvgIcon :name="val.meta.icon" />
          <span>{{ $t(val.meta.title) }}</span>
        </template>
        <!-- 加载children下面的二级路由 二级菜单-->
        <SubItem :chil="val.children"></SubItem>
      </el-sub-menu>
      <template v-else>
        <!-- 加载一级菜单,没带children，比如首页... -->
        <el-menu-item :index="val.path" :key="val.path">
          <SvgIcon :name="val.meta.icon"></SvgIcon>
          <template #title v-if="!val.meta.isLink || (val.meta.isLink && val.meta.isIframe)">
            <span>{{ $t(val.meta.title) }}</span>
          </template>
          <template #title v-else>
            <a class="w100" @click.prevent="onALinkClick(val)">{{ $t(val.meta.title) }}</a>
          </template>
        </el-menu-item>
      </template>
    </template>
  </el-menu>
</template>

<script setup lang="ts" name="navMenuVertical">
import { reactive, toRefs, onMounted, computed, watch, defineAsyncComponent } from 'vue'

import { useThemeConfig } from '/@/stores/themeConfig'
import { storeToRefs } from 'pinia';
import SvgIcon from '/@/components/svgIcon/index.vue';
import { useRoute, useRouter, onBeforeRouteUpdate } from 'vue-router';
import { verifyUrl } from '/@/utils/toolsValidate'

const SubItem = defineAsyncComponent(() => import('/@/layout/navMenu/subItem.vue'))
const storesThemeConfig = useThemeConfig()
const { themeConfig } = storeToRefs(storesThemeConfig)
//defineProps（defineProps是编译器宏，无需引入）定义props
const props = defineProps({
  menuList: {
    type: Array,
    default: () => []
  }
})
const { menuList } = toRefs(props)//toRefs()展示所有对象的属性

const menuLists = computed(() => {//左边菜单路由列表--核心
  //  console.log(menuList)
  return menuList.value as any
})

const getThemeConfig = computed(() => {
  return themeConfig.value
})

const route = useRoute()
const router = useRouter()
const state = reactive({
  defaultActive: route.meta.isDynamic ? route.meta.isDynamicPath : route.path,//defaultActive展开的index传递的是路由路径path-->isDynamicPath在route下面的index.ts // 判断是否是动态路由（xx/:id/:name），用于 tagsView 等中使用
  isCollapse: false,
})
const { defaultActive, isCollapse } = toRefs(state)

// 菜单高亮（详情时，父级高亮）--返回路径path
const setParentHighlight = (currentRoute: any) => {
  const { path, meta } = currentRoute
  const pathSplit = meta.isDynamic ? meta.isDynamicPath.split('/') : path.split('/')
  //pathSplit.splice(0,3).join('/')  返回删除后的数组，再与’/‘分割符拼接 比如pathSplit=['','limits','frontEnd','page']==>pathSplit.splice(0,3)返回 ['', 'limits', 'frontEnd']，之后数组转字符串 .join('/')==>/limits/frontEnd
  if (pathSplit.length >= 4 && meta.isHide) return pathSplit.splice(0, 3).join('/')//splice() 方法用于添加或删除数组中的元素，会改变原数组--》splice(index,number) index从第几个开始，number删除的个数
  else return path
}
// 打开外部链接
const onALinkClick = (val: any) => {
  const { origin, pathname } = window.location;
  router.push(val.path);
  if (verifyUrl(val.meta.isLink)) window.open(val.meta.isLink);
  else window.open(`${origin}${pathname}#${val.meta.isLink}`);
};
// 设置菜单的收起/展开--监听布局--》immediate如果为true 代表如果在 wacth 里声明了之后，就会立即先去执行里面的handler方法
// watch(themeConfig.value,()=>{console.log(themeConfig.value);document.body.clientWidth<=1000?(state.isCollapse=false):(state.isCollapse=themeConfig.value.isCollapse)},{immediate:true})
watch(themeConfig.value, () => { console.log(themeConfig.value); document.body.clientWidth <= 1000 ? (state.isCollapse = false) : (state.isCollapse = themeConfig.value.isCollapse) }, { immediate: true })
// 页面加载时
onMounted(() => {
  // debugger
  state.defaultActive = setParentHighlight(route)
})
// 路由更新时
onBeforeRouteUpdate((to) => {
  console.log(to)
  state.defaultActive = setParentHighlight(to)//核心，点击面包屑父级，左边菜单高亮效果
  const clientWidth = document.body.clientWidth
  if (clientWidth < 1000) themeConfig.value.isCollapse = false
})
</script>
<style lang='scss' scoped></style>